#ifndef __STATEVALIDITYCHECKER_H__
#define __STATEVALIDITYCHECKER_H__

#include <ompl/config.h>
#include <ompl/base/SpaceInformation.h>
#include <ompl/base/spaces/RealVectorStateSpace.h>
#include <ompl/geometric/planners/rrt/RRT.h>

#include <ompl/base/StateValidityChecker.h>
#include "dh.h"
#include "IRB140.h"
#include "PQP.h"

namespace ob = ompl::base;

class myStateValidityCheckerClass : public ob::StateValidityChecker
{	
public:
	myStateValidityCheckerClass(const ob::SpaceInformationPtr &si);
	virtual bool isValid(const ob::State *state) const;
	
		
	void loadCornerPoints();
	void importLink(const char *linkFil, std::vector<float > &linkVector, int linkNumber);
	int importEnvironment(const char *linkFil, PQP_Model &env, int numberOfTriangles);
	void AddCornerPoint(std::vector<float> point, std::vector<float> & corners);
	int createPQPModel(PQP_Model &model, ob::ProjectionMatrix::Matrix orientation, int numberOfTriangles, int linkNumber) const;
	int checkForSelfCollision(PQP_Model &m1, PQP_Model &m2, PQP_Model &m3, PQP_Model &m4, PQP_Model &m5, PQP_Model &m6) const;
	int checkForCollisionWithEnvironment(PQP_Model &env, PQP_Model &m1, PQP_Model &m2, PQP_Model &m3, PQP_Model &m4, PQP_Model &m5, PQP_Model &m6) const;
	
	PQP_Model getEnv() const;
	
private:
	std::vector<float> link1;
	std::vector<float> link2;
	std::vector<float> link3;
	std::vector<float> link4;
	std::vector<float> link5;
	std::vector<float> link6;
	
	
	ob::ProjectionMatrix::Matrix linkOne[36];
	ob::ProjectionMatrix::Matrix linkTwo[36];
	ob::ProjectionMatrix::Matrix linkThree[36];
	ob::ProjectionMatrix::Matrix linkFour[36];
	ob::ProjectionMatrix::Matrix linkFive[36];
	ob::ProjectionMatrix::Matrix linkSix[36];
	
	PQP_Model environment;
	int environmentTriangles;
};

#endif
